==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Polygon/group__PkgPolygon2Concepts.js <==
var group__PkgPolygon2Concepts =
[
    [ "GeneralPolygonWithHoles_2", "classGeneralPolygonWithHoles__2.html", [
      [ "Hole_const_iterator", "classGeneralPolygonWithHoles__2.html#ac963dd051fcfec8910308aa145d17e7d", null ],
      [ "Holes_container", "classGeneralPolygonWithHoles__2.html#a933430d675697d06640c3571af678b9e", null ],
      [ "Polygon_2", "classGeneralPolygonWithHoles__2.html#a62f717121c4f5f9242cf09023c12f975", null ],
      [ "GeneralPolygonWithHoles_2", "classGeneralPolygonWithHoles__2.html#a8c61ded65839bfb2f12d2a587a3d6ae9", null ],
      [ "add_hole", "classGeneralPolygonWithHoles__2.html#a4591a722c61eed6c75b2d53d22001cb5", null ],
      [ "clear", "classGeneralPolygonWithHoles__2.html#a2ca4d9b43cc9216c1b2cdb080a915944", null ],
      [ "clear_holes", "classGeneralPolygonWithHoles__2.html#a2a507be648f127ac605da8c670ea2580", null ],
      [ "clear_outer_boundary", "classGeneralPolygonWithHoles__2.html#a9f5f035047505a2ccab3e68770f51bc6", null ],
      [ "erase_hole", "classGeneralPolygonWithHoles__2.html#a6d6bee9d6ddd1c922d180fbcaebf3a91", null ],
      [ "has_holes", "classGeneralPolygonWithHoles__2.html#a5e60f3b6891f32dbfa1b8907207855da", null ],
      [ "holes", "classGeneralPolygonWithHoles__2.html#aa547209a83ac795d2822b887049b4509", null ],
      [ "holes_begin", "classGeneralPolygonWithHoles__2.html#a9d5b4cacd115c38667a2d024f239f8c6", null ],
      [ "holes_end", "classGeneralPolygonWithHoles__2.html#a931a7541f55a8a6dd505950cd3602029", null ],
      [ "is_unbounded", "classGeneralPolygonWithHoles__2.html#af8d95b3070ac1f72fc276260e86fd57e", null ],
      [ "number_of_holes", "classGeneralPolygonWithHoles__2.html#a567707b582310498a74dcc490d79fced", null ],
      [ "outer_boundary", "classGeneralPolygonWithHoles__2.html#a52b74b42a80ccde276b78b71a6c70cf4", null ]
    ] ],
    [ "PolygonTraits_2", "classPolygonTraits__2.html", [
      [ "Compare_x_2", "classPolygonTraits__2.html#a64bd0462d3ac54361b4c8d87531b16d6", null ],
      [ "Compare_y_2", "classPolygonTraits__2.html#ad3601e311a8d2a3038f15d3f61a86143", null ],
      [ "Compute_area_2", "classPolygonTraits__2.html#a1ac1caf99c0576da161384472a0d9593", null ],
      [ "Construct_segment_2", "classPolygonTraits__2.html#aa13da7b14b455e275736759088ac2592", null ],
      [ "Equal_2", "classPolygonTraits__2.html#aa128790eee7262736e3168baf6978cfb", null ],
      [ "FT", "classPolygonTraits__2.html#a52dfb75775945697ddf577928f7b3b09", null ],
      [ "Less_xy_2", "classPolygonTraits__2.html#aedaa9b73e2874506eb0769b93edb0ada", null ],
      [ "Less_yx_2", "classPolygonTraits__2.html#a19548e8494ecc0dc8673e926d85f6417", null ],
      [ "Orientation_2", "classPolygonTraits__2.html#aa7850dc245f0f33d9c84ec16e07b52bb", null ],
      [ "Point_2", "classPolygonTraits__2.html#acd5cecbca55e91ec8634f11a18dabeef", null ],
      [ "Segment_2", "classPolygonTraits__2.html#a588c242ba52896b89e69c5a116f73c2b", null ],
      [ "compare_x_2_object", "classPolygonTraits__2.html#aab746e7beeac7b74fbc92f24d014f253", null ],
      [ "compare_y_2_object", "classPolygonTraits__2.html#aa886b0492181871e920eaf56d880ed42", null ],
      [ "compute_area_2_object", "classPolygonTraits__2.html#ae850d545fe0a677891d3d39383a48807", null ],
      [ "construct_segment_2_object", "classPolygonTraits__2.html#ac227a24eb41fdf1579a905bd1820988e", null ],
      [ "equal_2_object", "classPolygonTraits__2.html#a2c62a25883c4348a38641fdee2da6493", null ],
      [ "less_xy_2_object", "classPolygonTraits__2.html#a170c0f93a35d5ff4c9509452e9ab516d", null ],
      [ "less_yx_2_object", "classPolygonTraits__2.html#abed1e7d144bde82550469cacc5a2266a", null ],
      [ "orientation_2_object", "classPolygonTraits__2.html#a54c70ec628b268cb93b0cb91762fafdf", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Polygon/group__PkgPolygon2Concepts.js <==
var group__PkgPolygon2Concepts =
[
    [ "GeneralPolygonWithHoles_2", "classGeneralPolygonWithHoles__2.html", [
      [ "Hole_const_iterator", "classGeneralPolygonWithHoles__2.html#ac963dd051fcfec8910308aa145d17e7d", null ],
      [ "Holes_container", "classGeneralPolygonWithHoles__2.html#a933430d675697d06640c3571af678b9e", null ],
      [ "Polygon_2", "classGeneralPolygonWithHoles__2.html#a62f717121c4f5f9242cf09023c12f975", null ],
      [ "GeneralPolygonWithHoles_2", "classGeneralPolygonWithHoles__2.html#a8c61ded65839bfb2f12d2a587a3d6ae9", null ],
      [ "add_hole", "classGeneralPolygonWithHoles__2.html#a4591a722c61eed6c75b2d53d22001cb5", null ],
      [ "clear", "classGeneralPolygonWithHoles__2.html#a2ca4d9b43cc9216c1b2cdb080a915944", null ],
      [ "clear_holes", "classGeneralPolygonWithHoles__2.html#a2a507be648f127ac605da8c670ea2580", null ],
      [ "clear_outer_boundary", "classGeneralPolygonWithHoles__2.html#a9f5f035047505a2ccab3e68770f51bc6", null ],
      [ "erase_hole", "classGeneralPolygonWithHoles__2.html#a6d6bee9d6ddd1c922d180fbcaebf3a91", null ],
      [ "has_holes", "classGeneralPolygonWithHoles__2.html#a5e60f3b6891f32dbfa1b8907207855da", null ],
      [ "holes", "classGeneralPolygonWithHoles__2.html#a419cd0ec4f64a7817f5216562d6888ee", null ],
      [ "holes_begin", "classGeneralPolygonWithHoles__2.html#a9d5b4cacd115c38667a2d024f239f8c6", null ],
      [ "holes_end", "classGeneralPolygonWithHoles__2.html#a931a7541f55a8a6dd505950cd3602029", null ],
      [ "is_unbounded", "classGeneralPolygonWithHoles__2.html#af8d95b3070ac1f72fc276260e86fd57e", null ],
      [ "number_of_holes", "classGeneralPolygonWithHoles__2.html#a567707b582310498a74dcc490d79fced", null ],
      [ "outer_boundary", "classGeneralPolygonWithHoles__2.html#a4ae04e904eefd2997a7604047f822d3a", null ]
    ] ],
    [ "MultipolygonWithHoles_2", "classMultipolygonWithHoles__2.html", [
      [ "Polygon_with_holes_2", "classMultipolygonWithHoles__2.html#afbbb8fa1b353c9a2b41a80feda2ee135", null ],
      [ "Polygon_with_holes_const_iterator", "classMultipolygonWithHoles__2.html#a7735729482c4a79f21fb635231719825", null ],
      [ "Polygon_with_holes_container", "classMultipolygonWithHoles__2.html#a577130c1b44f3b246f22929b3fe5877f", null ],
      [ "Polygon_with_holes_iterator", "classMultipolygonWithHoles__2.html#a28b8de4d9188c5faf77d831bec592a3d", null ],
      [ "Size", "classMultipolygonWithHoles__2.html#abeced9d6980500db96aa780f1596c3f9", null ],
      [ "MultipolygonWithHoles_2", "classMultipolygonWithHoles__2.html#a1ce4cb84345d6375071eb6544374d76c", null ],
      [ "add_polygon_with_holes", "classMultipolygonWithHoles__2.html#abac6486fbccd31e9f4cffe8416bac352", null ],
      [ "clear", "classMultipolygonWithHoles__2.html#a674441ebb3b055af2d31266469af34a0", null ],
      [ "erase_polygon_with_holes", "classMultipolygonWithHoles__2.html#ad685876f1e16fd08e8b7508904494597", null ],
      [ "number_of_polygons_wih_holes", "classMultipolygonWithHoles__2.html#a5cee5fb6ac97d220f41d30fc413e0d9c", null ],
      [ "polygons_with_holes", "classMultipolygonWithHoles__2.html#a360375582dee21606b6e1bce263083c9", null ],
      [ "polygons_with_holes_begin", "classMultipolygonWithHoles__2.html#aa32ed83721ebc83893dafd6b025ca904", null ],
      [ "polygons_with_holes_begin", "classMultipolygonWithHoles__2.html#a1952e0030e3ada4495002f411b80213e", null ],
      [ "polygons_with_holes_end", "classMultipolygonWithHoles__2.html#acbc714e298199259b93c8768575d2a91", null ],
      [ "polygons_with_holes_end", "classMultipolygonWithHoles__2.html#afff04f6cecdc80f685b493516cc978bf", null ]
    ] ],
    [ "PolygonTraits_2", "classPolygonTraits__2.html", [
      [ "Compare_x_2", "classPolygonTraits__2.html#a64bd0462d3ac54361b4c8d87531b16d6", null ],
      [ "Compare_y_2", "classPolygonTraits__2.html#ad3601e311a8d2a3038f15d3f61a86143", null ],
      [ "Compute_area_2", "classPolygonTraits__2.html#a1ac1caf99c0576da161384472a0d9593", null ],
      [ "Construct_segment_2", "classPolygonTraits__2.html#aa13da7b14b455e275736759088ac2592", null ],
      [ "Equal_2", "classPolygonTraits__2.html#aa128790eee7262736e3168baf6978cfb", null ],
      [ "FT", "classPolygonTraits__2.html#a52dfb75775945697ddf577928f7b3b09", null ],
      [ "Less_xy_2", "classPolygonTraits__2.html#aedaa9b73e2874506eb0769b93edb0ada", null ],
      [ "Less_yx_2", "classPolygonTraits__2.html#a19548e8494ecc0dc8673e926d85f6417", null ],
      [ "Orientation_2", "classPolygonTraits__2.html#aa7850dc245f0f33d9c84ec16e07b52bb", null ],
      [ "Point_2", "classPolygonTraits__2.html#acd5cecbca55e91ec8634f11a18dabeef", null ],
      [ "Segment_2", "classPolygonTraits__2.html#a588c242ba52896b89e69c5a116f73c2b", null ],
      [ "compare_x_2_object", "classPolygonTraits__2.html#aab746e7beeac7b74fbc92f24d014f253", null ],
      [ "compare_y_2_object", "classPolygonTraits__2.html#aa886b0492181871e920eaf56d880ed42", null ],
      [ "compute_area_2_object", "classPolygonTraits__2.html#ae850d545fe0a677891d3d39383a48807", null ],
      [ "construct_segment_2_object", "classPolygonTraits__2.html#ac227a24eb41fdf1579a905bd1820988e", null ],
      [ "equal_2_object", "classPolygonTraits__2.html#a2c62a25883c4348a38641fdee2da6493", null ],
      [ "less_xy_2_object", "classPolygonTraits__2.html#a170c0f93a35d5ff4c9509452e9ab516d", null ],
      [ "less_yx_2_object", "classPolygonTraits__2.html#abed1e7d144bde82550469cacc5a2266a", null ],
      [ "orientation_2_object", "classPolygonTraits__2.html#a54c70ec628b268cb93b0cb91762fafdf", null ]
    ] ]
];
